@@ -16,6 +16,7 @@ from threading import Lock
 from typing import List, Optional, Tuple, TypeVar, Union
 
 import aiohttp
+import numpy as np
 import PIL
 import PIL.Image  # type: ignore
 from fastapi.encoders import jsonable_encoder
@@ -24,6 +25,7 @@ from ..data_classes import ImageMetadata
 from ..enums import OutboxMode
 from ..globals import GLOBALS
 from ..helpers import environment_reader, run
+from ..helpers.misc import numpy_array_to_jpg_bytes
 
 T = TypeVar('T')
 
@@ -76,25 +78,24 @@ class Outbox():
             self.upload_folders.append(file)
 
     async def save(self,
-                   image: bytes,
+                   image: np.ndarray,
                    image_metadata: Optional[ImageMetadata] = None,
-                   tags: Optional[List[str]] = None,
-                   source: Optional[str] = None,
-                   creation_date: Optional[str] = None,
                    upload_priority: bool = False) -> None:
+        """
+        Save an image and its metadata to disk. 
 
-        if not await run.io_bound(self._is_valid_jpg, image):
-            self.log.error('Invalid jpg image')
-            return
+        The data will be picked up by the continuous upload process.
+        """
+
+        jpg_bytes = numpy_array_to_jpg_bytes(image)
 
         if image_metadata is None:
             image_metadata = ImageMetadata()
-        if not tags:
-            tags = []
+
         identifier = datetime.now().isoformat(sep='_', timespec='microseconds')
 
         try:
-            await run.io_bound(self._save_files_to_disk, identifier, image, image_metadata, tags, source, creation_date, upload_priority)
+            await run.io_bound(self._save_files_to_disk, identifier, jpg_bytes, image_metadata, upload_priority)
         except Exception as e:
             self.log.error('Failed to save files for image %s: %s', identifier, e)
             return
@@ -108,11 +109,8 @@ class Outbox():
 
     def _save_files_to_disk(self,
                             identifier: str,
-                            image: bytes,
+                            jpeg_image: bytes,
                             image_metadata: ImageMetadata,
-                            tags: List[str],
-                            source: Optional[str],
-                            creation_date: Optional[str],
                             upload_priority: bool) -> None:
         subpath = 'priority' if upload_priority else 'normal'
         full_path = f'{self.path}/{subpath}/{identifier}'
@@ -120,25 +118,18 @@ class Outbox():
             raise FileExistsError(f'Directory with identifier {identifier} already exists')
 
         tmp = f'{GLOBALS.data_folder}/tmp/{identifier}'
-        image_metadata.tags = tags
-        if self._is_valid_isoformat(creation_date):
-            image_metadata.created = creation_date
-        else:
-            image_metadata.created = identifier
-
-        image_metadata.source = source or 'unknown'
-
         os.makedirs(tmp, exist_ok=True)
 
         with open(tmp + f'/image_{identifier}.json', 'w') as f:
             json.dump(jsonable_encoder(asdict(image_metadata)), f)
 
         with open(tmp + f'/image_{identifier}.jpg', 'wb') as f:
-            f.write(image)
+            f.write(jpeg_image)
 
         if not os.path.exists(tmp):
             self.log.error('Could not rename %s to %s', tmp, full_path)
             raise FileNotFoundError(f'Could not rename {tmp} to {full_path}')
+
         os.rename(tmp, full_path)
 
     async def _trim_upload_queue(self) -> None:
